@@ -55,8 +55,8 @@ def remove_incompatible_characters(string):
 
     string = list(string)
 
-    for idx in range(len(string)):  # pylint: disable=consider-using-enumerate
-        code = ord(string[idx])
+    for idx, char in enumerate(string):
+        code = ord(char)
         if (0 <= code <= 8) or (11 <= code <= 12) or (14 <= code <= 31):
             string[idx] = " "
 
@@ -193,7 +193,7 @@ def ssml_headers_plus_data(request_id, timestamp, ssml):
     )
 
 
-class Communicate:  # pylint: disable=too-few-public-methods
+class Communicate:
     """
     Class for communicating with the service.
     """
@@ -213,9 +213,8 @@ class Communicate:  # pylint: disable=too-few-public-methods
         pitch="+0Hz",
         rate="+0%",
         volume="+0%",
-        customspeak=False,
         proxy=None,
-    ):  # pylint: disable=too-many-arguments, too-many-locals
+    ):
         """
         Runs the Communicate class.
 
@@ -223,51 +222,42 @@ class Communicate:  # pylint: disable=too-few-public-methods
             messages (str or list): A list of SSML strings or a single text.
             boundery_type (int): The type of boundary to use. 0 for none, 1 for word_boundary, 2 for sentence_boundary.
             codec (str): The codec to use.
-            voice (str): The voice to use (only applicable to non-customspeak).
-            pitch (str): The pitch to use (only applicable to non-customspeak).
-            rate (str): The rate to use (only applicable to non-customspeak).
-            volume (str): The volume to use (only applicable to non-customspeak).
-            customspeak (bool): Whether to create the SSML or treat the messages as SSML.
+            voice (str): The voice to use.
+            pitch (str): The pitch to use.
+            rate (str): The rate to use.
+            volume (str): The volume to use.
 
         Yields:
             tuple: The subtitle offset, subtitle, and audio data.
         """
 
         word_boundary = False
-        sentence_boundary = False
 
         if boundary_type > 0:
             word_boundary = True
         if boundary_type > 1:
-            sentence_boundary = True
+            raise ValueError(
+                "Invalid boundary type. SentenceBoundary is no longer supported."
+            )
 
-        sentence_boundary = str(sentence_boundary).lower()
         word_boundary = str(word_boundary).lower()
 
-        if not customspeak:
-            websocket_max_size = 2**16
-            overhead_per_message = (
-                len(
-                    ssml_headers_plus_data(
-                        connect_id(), self.date, mkssml("", voice, pitch, rate, volume)
-                    )
+        websocket_max_size = 2**16
+        overhead_per_message = (
+            len(
+                ssml_headers_plus_data(
+                    connect_id(), self.date, mkssml("", voice, pitch, rate, volume)
                 )
-                + 50
-            )  # margin of error
-            messages = split_text_by_byte_length(
-                escape(remove_incompatible_characters(messages)),
-                websocket_max_size - overhead_per_message,
             )
-        else:
-            if isinstance(messages, str):
-                messages = [messages]
-
+            + 50
+        )  # margin of error
+        messages = split_text_by_byte_length(
+            escape(remove_incompatible_characters(messages)),
+            websocket_max_size - overhead_per_message,
+        )
 
         # Variables for the loop
         download = False
-        current_subtitle = ""
-        first_offset = None
-        last_offset = None
         async with aiohttp.ClientSession(trust_env=True) as session:
             async with session.ws_connect(
                 f"{WSS_URL}&ConnectionId={connect_id()}",
@@ -304,34 +294,23 @@ class Communicate:  # pylint: disable=too-few-public-methods
                         "Content-Type:application/json; charset=utf-8\r\n"
                         "Path:speech.config\r\n\r\n"
                         '{"context":{"synthesis":{"audio":{"metadataoptions":{'
-                        f'"sentenceBoundaryEnabled":{sentence_boundary},'
+                        f'"sentenceBoundaryEnabled":false,'
                         f'"wordBoundaryEnabled":{word_boundary}}},"outputFormat":"{codec}"'
                         "}}}}\r\n"
                     )
                     # Send the request to the service.
                     await websocket.send_str(request)
                     # Send the message itself.
-                    if not customspeak:
-                        await websocket.send_str(
-                            ssml_headers_plus_data(
-                                connect_id(),
-                                self.date,
-                                mkssml(message, voice, pitch, rate, volume),
-                            )
-                        )
-                    else:
-                        await websocket.send_str(
-                            ssml_headers_plus_data(connect_id(), self.date, message)
+                    await websocket.send_str(
+                        ssml_headers_plus_data(
+                            connect_id(),
+                            self.date,
+                            mkssml(message, voice, pitch, rate, volume),
                         )
+                    )
 
                     # Begin listening for the response.
                     async for received in websocket:
-                        if received.type in (
-                            aiohttp.WSMsgType.CLOSED,
-                            aiohttp.WSMsgType.ERROR,
-                        ):
-                            break
-
                         if received.type == aiohttp.WSMsgType.TEXT:
                             parameters, data = get_headers_and_data(received.data)
                             if (
@@ -358,12 +337,15 @@ class Communicate:  # pylint: disable=too-few-public-methods
                                     metadata_duration = metadata["Metadata"][0]["Data"][
                                         "Duration"
                                     ]
-                                except KeyError:
-                                    metadata_duration = 0
+                                except KeyError as exception:
+                                    raise ValueError(
+                                        "The metadata doesn't contain a Duration field. "
+                                        + "This usually happens when SentenceBoundary metadata type is sent."
+                                    ) from exception
                                 metadata_text = metadata["Metadata"][0]["Data"]["text"][
                                     "Text"
                                 ]
-                                if boundary_type == 1:
+                                if metadata_type == "WordBoundary":
                                     yield (
                                         [
                                             metadata_offset,
@@ -372,31 +354,32 @@ class Communicate:  # pylint: disable=too-few-public-methods
                                         metadata_text,
                                         None,
                                     )
+                                elif metadata_type == "SentenceBoundary":
+                                    raise NotImplementedError(
+                                        "SentenceBoundary is not supported due to being broken."
+                                    )
                                 else:
-                                    if metadata_type == "WordBoundary":
-                                        if current_subtitle:
-                                            current_subtitle += " "
-                                        current_subtitle += metadata_text
-                                        if first_offset is None:
-                                            first_offset = metadata_offset
-                                        last_offset = [
-                                            metadata_offset,
-                                            metadata_duration,
-                                        ]
-                                    elif metadata_type == "SentenceBoundary":
-                                        if current_subtitle:
-                                            yield (
-                                                [
-                                                    first_offset,
-                                                    sum(last_offset) - first_offset,
-                                                ],
-                                                current_subtitle,
-                                                None,
-                                            )
-                                        current_subtitle = ""
-                                        first_offset = None
-                                        last_offset = None
+                                    raise NotImplementedError(
+                                        f"Unknown metadata type: {metadata_type}"
+                                    )
+                            elif (
+                                "Path" in parameters
+                                and parameters["Path"] == "response"
+                            ):
+                                # TODO: implement this:
+                                """
+                                X-RequestId:xxxxxxxxxxxxxxxxxxxxxxxxx
+                                Content-Type:application/json; charset=utf-8
+                                Path:response
 
+                                {"context":{"serviceTag":"yyyyyyyyyyyyyyyyyyy"},"audio":{"type":"inline","streamId":"zzzzzzzzzzzzzzzzz"}}
+                                """
+                                pass
+                            else:
+                                raise ValueError(
+                                    "The response from the service is not recognized.\n"
+                                    + received.data
+                                )
                         elif received.type == aiohttp.WSMsgType.BINARY:
                             if download:
                                 yield (
@@ -406,10 +389,8 @@ class Communicate:  # pylint: disable=too-few-public-methods
                                         received.data.split(b"Path:audio\r\n")[1:]
                                     ),
                                 )
-                if current_subtitle:
-                    yield (
-                        [first_offset, sum(last_offset) - first_offset],
-                        current_subtitle,
-                        None,
-                    )
+                            else:
+                                raise ValueError(
+                                    "The service sent a binary message, but we are not expecting one."
+                                )
                 await websocket.close()
